==> nextcloud-app-calendar-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/th.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ปฏิทิน",
    "Individual" : "ของแต่ละบุคคล",
    "Group" : "กลุ่ม",
    "Resource" : "ทรัพยากร",
    "Room" : "ห้อง",
    "Unknown" : "ไม่ทราบ",
    "Required" : "ที่จำเป็น",
    "Optional" : "ตัวเลือก",
    "Does not attend" : "ไม่ได้เข้าร่วม",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "คุณอยู่ในเขตเวลาที่ไม่รู้จัก ({tz}), กำลงกลับไปสู่ UTC",
    "Please create a calendar first." : "กรุณาสร้างปฏิทินก่อน",
    "New event" : "เหตุการณ์ใหม่",
    "Some events in this calendar are broken. Please check the JS console for more info." : "เหตุการณ์บางอย่างในปฏิทินนี้เสียหาย กรุณาตรวจสอบคอนโซล JS สำหรับข้อมูลเพิ่มเติม",
    "Share Calendar" : "เปิดแชร์ปฏิทิน",
    "Shared" : "แชร์แล้ว",
    "group" : "กลุ่มผู้ใช้งาน",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Reminders" : "การแจ้งเตือน",
    "Repeating" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Confirmed" : "ได้รับการยืนยันแล้ว",
    "Tentative" : "ชั่วคราว",
    "Cancelled" : "ยกเลิกแล้ว",
    "Global" : "ทั่วไป",
    "None" : "ไม่มี",
    "Every day" : "ทุกวัน",
    "Every week" : "ทุกสัปดาห์",
    "Every month" : "ทุกเดือน",
    "Every year" : "ทุกปี",
    "never" : "ไม่ต้องเลย",
    "after" : "หลัง",
    "At time of event" : "ในช่วงเวลาของเหตุการณ์",
    "5 minutes before" : "5 นาทีก่อนหน้านั้น",
    "10 minutes before" : "10 นาทีก่อนหน้านั้น",
    "15 minutes before" : "15 นาทีก่อนหน้านั้น",
    "30 minutes before" : "30 นาทีก่อนหน้านั้น",
    "1 hour before" : "1 ชั่วโมงก่อนหน้านั้น",
    "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
    "Custom" : "กำหนดเอง",
    "Audio" : "เสียง",
    "Pop-up" : "ป๊อปอัพ",
    "sec" : "วินาที",
    "min" : "นาที",
    "hours" : "ชั่วโมง",
    "days" : "วัน",
    "week" : "สัปดาห์",
    "before" : "ก่อน",
    "start" : "เริ่ม",
    "end" : "จบ",
    "Editing reminders of unknown type not supported." : "แจ้งเตือนการแก้ไขที่ไม่รู้จัก ไม่ได้รับการสนับสนุน",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "{type} {time} before the event starts" : "{type} {time} ก่อนที่เหตุการณ์จะเริ่มต้น",
    "{type} {time} before the event ends" : "{type} {time} ก่อนที่เหตุการณ์จะจบลง",
    "{type} {time} after the event starts" : "{type} {time} หลังจากที่เริ่มต้นเหตุการณ์",
    "{type} {time} after the event ends" : "{type} {time} หลังจากที่เหตุการณ์จบลง",
    "{type} at the event's start" : "{type} ในช่วงที่เหตุการณ์เริ่มต้น",
    "{type} at the event's end" : "{type} ในช่วงที่เหตุการณ์จบลง",
    "{type} at {time}" : "{type} ตอน {time}",
    "{calendar} shared by {owner}" : "{calendar} ถูกแชร์โดย {owner}",
    "Title of the Event" : "ชื่อของกิจกรรม",
    "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
    "Delete" : "ลบ",
    "Cancel" : "ยกเลิก",
    "More ..." : "เพิ่มเติม ...",
    "Create" : "สร้าง",
    "Update" : "อัพเดท",
    "Close" : "ปิด",
    "Location" : "ตำแหน่งที่อยู่",
    "Description" : "รายละเอียด",
    "Event status" : "สถานะเหตุการณ์",
    "Visibility when sharing" : "แสดงผลเมื่อมีการแชร์",
    "Export" : "ส่งออก",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Today" : "วันนี้",
    "More" : "เพิ่มเติม",
    "Edit" : "แก้ไข",
    "Link" : "ลิงค์",
    "Download" : "ดาวน์โหลด",
    "can edit" : "สามารถแก้ไข",
    "New Calendar" : "สร้างปฏิทินใหม่",
    "Name" : "ชื่อ",
    "New Subscription" : "สมัครสมาชิกใหม่",
    "Edit event" : "แก้ไขกิจกรรม",
    "Delete Event" : "ลบเหตุการณ์",
    "Save Event" : "บันทึกเหตุการณ์",
    "Time" : "เวลา",
    "Type" : "ประเภท",
    "Relative" : "เครื่องญาติ",
    "Absolute" : "สมบูรณ์",
    "Repeat" : "ทำซ้ำ",
    "times every" : "ทุกครั้ง",
    "Add" : "เพิ่ม",
    "Please add your email address in the personal settings in order to add attendees." : "กรุณาเพิ่มที่อยู่อีเมลของคุณในการตั้งค่าส่วนบุคคลเพื่อเพิ่มผู้เข้าร่วมประชุม",
    "from" : "จาก",
    "to" : "ถึง",
    "This event's repeating rule is not supported yet." : "กฎการทำซ้ำของเหตุการณ์นี้ยังไม่ได้รับการสนับสนุน",
    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการอัพเดท",
    "Reset repeating rule" : "รีเซ็ตกฎการทำซ้ำ",
    "Repeat every ..." : "ทำซ้ำตลอด ...",
    "end repeat ..." : "ยกเลิกการทำซ้ำ ...",
    "times" : "ครั้ง",
    "Import Calendars" : "นำเข้าปฏิทิน",
    "Import canceled" : "การนำเข้าถูกยกเลิก",
    "Analyzing calendar" : "วิเคราะห์ปฏิทิน",
    "The file contains objects incompatible with the selected calendar" : "ไฟล์ประกอบด้วยวัตถุเข้ากันไม่ได้กับปฏิทินที่เลือก",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Import scheduled" : "นำเข้าตารางเวลาตามที่กำหนดไว้",
    "Import calendar" : "นำเข้าปฏิทิน",
    "No Calendars selected for import" : "ไม่มีปฏิทินที่เลือกนำเข้า",
    "Skip simple event editor" : "ข้ามการแก้ไขกิจกรรมอย่างง่าย",
    "Primary CalDAV address" : "ที่อยู่ CalDAV หลัก"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/th.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ปฏิทิน",
    "Cheers!" : "ไชโย!",
    "Today" : "วันนี้",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Download" : "ดาวน์โหลด",
    "Delete" : "ลบ",
    "Share link" : "แชร์ลิงค์",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Cancel" : "ยกเลิก",
    "Automatic" : "อัตโนมัติ",
    "Email" : "อีเมล",
    "Unknown" : "ไม่ทราบ",
    "from" : "จาก",
    "to" : "ถึง",
    "never" : "ไม่ต้องเลย",
    "after" : "หลัง",
    "Repeat" : "ทำซ้ำ",
    "Monday" : "วันจันทร์",
    "More" : "เพิ่มเติม",
    "Save" : "บันทึก",
    "Update" : "อัพเดท",
    "Personal" : "ส่วนตัว",
    "Details" : "รายละเอียด",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Reminders" : "การแจ้งเตือน",
    "Activity" : "กิจกรรม",
    "Close" : "ปิด",
    "Anniversary" : "วันครบรอบ",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Daily" : "รุ่นรายวัน",
    "Weekly" : "รายสัปดาห์",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Location" : "ตำแหน่งที่อยู่",
    "Description" : "รายละเอียด",
    "Confirmed" : "ได้รับการยืนยันแล้ว",
    "Tentative" : "ชั่วคราว",
    "Cancelled" : "ยกเลิกแล้ว",
    "Presentation" : "งานนำเสนอ",
    "Office" : "สำนักงาน",
    "Mail" : "จดหมาย",
    "Play" : "เล่น",
    "Global" : "ทั่วไป"
},
"nplurals=1; plural=0;");
